var title = "Calories";
var limit = 2500;
var unit = "kcal";
var current = 0;

function setup() {
  if (window.widget) {
    widgetSetup();
    readPrefs();
    widget.onremove = clearPrefs;
    widget.onshow = onshow;
    widget.onhide = onhide;
    if (widget.context) {
      document.getElementById("Widgetop").style.display = "none";
    }
  }
}

function readPrefs() {
  if (window.widget) {
    var value = widget.preferenceForKey(widget.identifier + "-current");
    if (value) {
      current = parseInt(value);
    }

    var value = widget.preferenceForKey(widget.identifier + "-limit");
    if (value) {
      limit = parseInt(value);
    }
    document.getElementById("LimitInput").value = limit;  
    
    var value = widget.preferenceForKey(widget.identifier + "-unit");
    if (value) {
      unit = value;
    }
    document.getElementById("UnitInput").value = unit;  

    var value = widget.preferenceForKey(widget.identifier + "-title");
    if (value) {
      title = value;
    }
    document.getElementById("TitleInput").value = title;  
    
    update();
  }
}

function clearPrefs() {
  widget.setPreferenceForKey(null, widget.identifier + "-current");
  widget.setPreferenceForKey(null, widget.identifier + "-limit");
  widget.setPreferenceForKey(null, widget.identifier + "-unit");
  widget.setPreferenceForKey(null, widget.identifier + "-title");
}

function onshow() {
}

function onhide() {
}

function update() {
  limit = parseInt($("LimitInput").value);
  unit = $("UnitInput").value;
  title = $("TitleInput").value;
  $("Title").innerHTML = title;
  widget.setPreferenceForKey(limit, widget.identifier + "-limit");
  widget.setPreferenceForKey(unit, widget.identifier + "-unit");
  widget.setPreferenceForKey(title, widget.identifier + "-title");
  updateCurrent();
}

function updateCurrent() {  
  $("SummaryLimit").innerHTML = limit + "&nbsp;" + unit;
  $("GraphLimit").innerHTML = limit + "&nbsp;" + unit;
  $("SummaryValue").innerHTML = current + "&nbsp;" + unit;    
  $("SummaryPercent").innerHTML = parseInt(100 * current / limit);
  if (current > limit) {
    $("SummaryValue").style.color = "orange";
    $("SummaryPercent").style.color = "orange";
  } else {
    $("SummaryValue").style.color = "white";
    $("SummaryPercent").style.color = "white";      
  }
  $("GraphValue").innerHTML = current + "&nbsp;" + unit;
  widget.setPreferenceForKey(current, widget.identifier + "-current");
  updateGraph();
}

function updateGraph() {
  var width = 210;
  if (current < limit * 1.5) {
    var left = 160;
    $("LeftBar1").width = left;
    $("LeftBar2").width = left;
    $("RightBar1").width = width - left - 1;
    $("RightBar2").width = width - left - 1;
    var bar = Math.min(width - 1, 2 + (left - 2) * current / limit);
    $("ForeBar").width = bar;
    $("GraphBackground2").style.width = bar + "px";
    $("GraphLimit").style.left = left - 25 + "px";
    $("GraphValue").style.left = Math.min(Math.max(0, bar - 25), width - 50) + "px";
  }
  else {
    var size = width * limit * 1.5 / current;
    var left = size / 1.5;
    $("LeftBar1").width = left;
    $("LeftBar2").width = left;
    $("RightBar1").width = size - left;
    $("RightBar2").width = size - left;
    var bar = width;
    $("ForeBar").width = bar;
    $("GraphBackground2").style.width = bar + "px";
    $("GraphLimit").style.left = Math.max(0, left - 25) + "px";
    $("GraphValue").style.left = width - 50 + "px";
  }
}
  
function valueAdded() {
  var value = parseFloat($("AddInput").value);
  if (isNaN(value)) {
    return;
  }
  $("AddInput").value = "";
  if (current <= limit && current + value > limit) {
    $("Alert").style.display = "block";
  }
  current += value;
  updateCurrent();
}

function reset() {
  current = 0;
  updateCurrent();
}

function closeAlert() {
  document.getElementById("Alert").style.display = "none";
}

function showHelp() {
  document.getElementById("Help").style.display = "block";
}

function closeHelp() {
  document.getElementById("Help").style.display = "none";  
}

function widgetSetup() {
  if (window.widget) {
  	var gDoneButton = new AppleGlassButton(document.getElementById("DoneButton"), 
  	                                      "Done", hideBack); 
  	var gHelpButton = new AppleGlassButton(document.getElementById("HelpButton"), 
  	                                      "Help", showHelp); 
  	/*
  	var gAddButton = new AppleGlassButton(document.getElementById("AddButton"), 
  	                                      "Add", valueAdded); 
  	*/
  	var gResetButton = new AppleGlassButton(document.getElementById("ResetButton"), 
  	                                      "Reset", reset); 
	  var gInfoButton = new AppleInfoButton(document.getElementById("InfoButton"), 
	                                        document.getElementById("front"), 
	                                        "white", "white", showBack);    
  }
}

function showBack() {
    var front = document.getElementById("front");
    var back = document.getElementById("back");
 
    if(window.widget)
        widget.prepareForTransition("ToBack");
 
    front.style.display="none";
    window.resizeTo(220, 290);
    back.style.display="block";
 
    if (window.widget)
        setTimeout ('widget.performTransition();', 0);  
}

function hideBack() {
    var front = document.getElementById("front");
    var back = document.getElementById("back");
 
    if (window.widget)
        widget.prepareForTransition("ToFront");
 
    back.style.display="none";
    window.resizeTo(270, 160);
    update();
    front.style.display="block";
 
    if (window.widget)
        setTimeout ('widget.performTransition();', 0);
}

function $(id) {
  return document.getElementById(id);
}

if (top.myBrowser && top.myBrowser.needsXMLHttpRequestVariable) {var XMLHttpRequest;}